==> ejc-production-api-3.0.0-20220504.015538-94-sources.jar: com/ejianc/business/production/task/vo/ProductionTaskApiVo.java <==
package com.ejianc.business.production.task.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

public class ProductionTaskApiVo extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long customerManageId; // 客户管理档案id
    private String customerManageName; // 客户管理档案名称
    private Long projectId; // 工程id
    private String projectName; // 工程名称
    private Long worksiteId; // 工地id
    private String worksiteName; // 工地名称
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称
    private BigDecimal distance; // 距离
    private Long productId; // 产品id
    private String productName; // 产品名称
    private String carCode; // 车号
    private String shipperMName; //运输商基本信息名称
    private Long shipperId; //运输商Id
    private Long shipperVehicleId; //运输商车辆ID
    private String shipperVehicleName; //运输商车辆名称
    private BigDecimal tare; //皮重
    private Integer category;//车辆类别
    private String transportMethod; //运输商车辆名称
    private Long unitId; // 机组id
    private String unitName; // 机组名称
    private Long transPortId; // 运输信息主键id

    List<ShipperfareVO> shipperfareVOS =new ArrayList<>();



    @ReferSerialTransfer(referCode="CustomermanageRef")
    public Long getCustomerManageId() {
        return customerManageId;
    }
    @ReferDeserialTransfer
    public void setCustomerManageId(Long customerManageId) {
        this.customerManageId = customerManageId;
    }
    public String getCustomerManageName() {
        return customerManageName;
    }

    public void setCustomerManageName(String customerManageName) {
        this.customerManageName = customerManageName;
    }
    @ReferSerialTransfer(referCode="ProjectInfoRef")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    @ReferSerialTransfer(referCode="ConstructionsiteRef")
    public Long getWorksiteId() {
        return worksiteId;
    }
    @ReferDeserialTransfer
    public void setWorksiteId(Long worksiteId) {
        this.worksiteId = worksiteId;
    }
    public String getWorksiteName() {
        return worksiteName;
    }

    public void setWorksiteName(String worksiteName) {
        this.worksiteName = worksiteName;
    }

    public BigDecimal getDistance() {
        return distance;
    }

    public void setDistance(BigDecimal distance) {
        this.distance = distance;
    }

    @ReferSerialTransfer(referCode="ProductorInfoRef")
    public Long getProductId() {
        return productId;
    }
    @ReferDeserialTransfer
    public void setProductId(Long productId) {
        this.productId = productId;
    }
    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public String getCarCode() {
        return carCode;
    }

    public void setCarCode(String carCode) {
        this.carCode = carCode;
    }

    public String getShipperMName() {
        return shipperMName;
    }

    public void setShipperMName(String shipperMName) {
        this.shipperMName = shipperMName;
    }
    @ReferSerialTransfer(referCode="ProductorInfoRef")
    public Long getShipperId() {
        return shipperId;
    }
    @ReferDeserialTransfer
    public void setShipperId(Long shipperId) {
        this.shipperId = shipperId;
    }
    @ReferSerialTransfer(referCode="ProductorInfoRef")
    public Long getShipperVehicleId() {
        return shipperVehicleId;
    }
    @ReferDeserialTransfer
    public void setShipperVehicleId(Long shipperVehicleId) {
        this.shipperVehicleId = shipperVehicleId;
    }

    public String getShipperVehicleName() {
        return shipperVehicleName;
    }

    public void setShipperVehicleName(String shipperVehicleName) {
        this.shipperVehicleName = shipperVehicleName;
    }

    public List<ShipperfareVO> getShippersfareVOS() {
        return shipperfareVOS;
    }

    public void setShippersfareVOS(List<ShipperfareVO> shipperfareVOS) {
        this.shipperfareVOS = shipperfareVOS;
    }

    public BigDecimal getTare() {
        return tare;
    }

    public void setTare(BigDecimal tare) {
        this.tare = tare;
    }

    public Integer getCategory() {
        return category;
    }

    public void setCategory(Integer category) {
        this.category = category;
    }
    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgId() {
        return orgId;
    }
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getTransportMethod() {
        return transportMethod;
    }

    public void setTransportMethod(String transportMethod) {
        this.transportMethod = transportMethod;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }

    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }

    public Long getTransPortId() {
        return transPortId;
    }

    public void setTransPortId(Long transPortId) {
        this.transPortId = transPortId;
    }
}

==> ejc-production-api-3.0.0-20220514.072023-107-sources.jar: com/ejianc/business/production/task/vo/ProductionTaskApiVo.java <==
package com.ejianc.business.production.task.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

public class ProductionTaskApiVo extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long customerManageId; // 客户管理档案id
    private String customerManageName; // 客户管理档案名称
    private Long projectId; // 工程id
    private String projectName; // 工程名称
    private Long worksiteId; // 工地id
    private String worksiteName; // 工地名称
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称
    private BigDecimal distance; // 距离
    private Long productId; // 产品id
    private String productName; // 产品名称
    private String carCode; // 车号
    private String shipperMName; //运输商基本信息名称
    private Long shipperId; //运输商Id
    private Long shipperVehicleId; //运输商车辆ID
    private String shipperVehicleName; //运输商车辆名称
    private BigDecimal tare; //皮重
    private Integer category;//车辆类别
    private String transportMethod; //运输商车辆名称
    private Long unitId; // 机组id
    private String unitName; // 机组名称
    private Long transPortId; // 运输信息主键id
    private String orderName; // 定料人
    private String orderMobile; // 联系电话
    private String transportRoute; // 行车路线
    private String materialVarieties; // 原材料品种
    private String materialSpec; // 原材料规格

    List<ShipperfareVO> shipperfareVOS =new ArrayList<>();



    @ReferSerialTransfer(referCode="CustomermanageRef")
    public Long getCustomerManageId() {
        return customerManageId;
    }
    @ReferDeserialTransfer
    public void setCustomerManageId(Long customerManageId) {
        this.customerManageId = customerManageId;
    }
    public String getCustomerManageName() {
        return customerManageName;
    }

    public void setCustomerManageName(String customerManageName) {
        this.customerManageName = customerManageName;
    }
    @ReferSerialTransfer(referCode="ProjectInfoRef")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    @ReferSerialTransfer(referCode="ConstructionsiteRef")
    public Long getWorksiteId() {
        return worksiteId;
    }
    @ReferDeserialTransfer
    public void setWorksiteId(Long worksiteId) {
        this.worksiteId = worksiteId;
    }
    public String getWorksiteName() {
        return worksiteName;
    }

    public void setWorksiteName(String worksiteName) {
        this.worksiteName = worksiteName;
    }

    public BigDecimal getDistance() {
        return distance;
    }

    public void setDistance(BigDecimal distance) {
        this.distance = distance;
    }

    @ReferSerialTransfer(referCode="ProductorInfoRef")
    public Long getProductId() {
        return productId;
    }
    @ReferDeserialTransfer
    public void setProductId(Long productId) {
        this.productId = productId;
    }
    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public String getCarCode() {
        return carCode;
    }

    public void setCarCode(String carCode) {
        this.carCode = carCode;
    }

    public String getShipperMName() {
        return shipperMName;
    }

    public void setShipperMName(String shipperMName) {
        this.shipperMName = shipperMName;
    }
    @ReferSerialTransfer(referCode="ProductorInfoRef")
    public Long getShipperId() {
        return shipperId;
    }
    @ReferDeserialTransfer
    public void setShipperId(Long shipperId) {
        this.shipperId = shipperId;
    }
    @ReferSerialTransfer(referCode="ProductorInfoRef")
    public Long getShipperVehicleId() {
        return shipperVehicleId;
    }
    @ReferDeserialTransfer
    public void setShipperVehicleId(Long shipperVehicleId) {
        this.shipperVehicleId = shipperVehicleId;
    }

    public String getShipperVehicleName() {
        return shipperVehicleName;
    }

    public void setShipperVehicleName(String shipperVehicleName) {
        this.shipperVehicleName = shipperVehicleName;
    }

    public List<ShipperfareVO> getShippersfareVOS() {
        return shipperfareVOS;
    }

    public void setShippersfareVOS(List<ShipperfareVO> shipperfareVOS) {
        this.shipperfareVOS = shipperfareVOS;
    }

    public BigDecimal getTare() {
        return tare;
    }

    public void setTare(BigDecimal tare) {
        this.tare = tare;
    }

    public Integer getCategory() {
        return category;
    }

    public void setCategory(Integer category) {
        this.category = category;
    }
    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgId() {
        return orgId;
    }
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getTransportMethod() {
        return transportMethod;
    }

    public void setTransportMethod(String transportMethod) {
        this.transportMethod = transportMethod;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }

    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }

    public Long getTransPortId() {
        return transPortId;
    }

    public void setTransPortId(Long transPortId) {
        this.transPortId = transPortId;
    }

    public String getOrderName() {
        return orderName;
    }

    public void setOrderName(String orderName) {
        this.orderName = orderName;
    }

    public String getOrderMobile() {
        return orderMobile;
    }

    public void setOrderMobile(String orderMobile) {
        this.orderMobile = orderMobile;
    }

    public String getTransportRoute() {
        return transportRoute;
    }

    public void setTransportRoute(String transportRoute) {
        this.transportRoute = transportRoute;
    }

    public String getMaterialVarieties() {
        return materialVarieties;
    }

    public void setMaterialVarieties(String materialVarieties) {
        this.materialVarieties = materialVarieties;
    }

    public String getMaterialSpec() {
        return materialSpec;
    }

    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }
}
